@@ -1,13 +1,12 @@
-# encoding: utf-8
-# Copyright (C) 2012-2021 jrnl contributors
+# Copyright (C) 2012-2022 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
-
 import codecs
 import fnmatch
 import os
 
-from . import Journal
+from jrnl import Journal
+from jrnl import time
 
 
 def get_files(journal_config):
@@ -80,7 +79,6 @@ class Folder(Journal.Journal):
         filenames = get_files(self.config["journal"])
         for filename in filenames:
             if os.stat(filename).st_size <= 0:
-                # print("empty file: {}".format(filename))
                 os.remove(filename)
 
     def delete_entries(self, entries_to_delete):
@@ -89,6 +87,17 @@ class Folder(Journal.Journal):
             self.entries.remove(entry)
             self._diff_entry_dates.append(entry.date)
 
+    def change_date_entries(self, date):
+        """Changes entry dates to given date."""
+
+        date = time.parse(date)
+
+        self._diff_entry_dates.append(date)
+
+        for entry in self.entries:
+            self._diff_entry_dates.append(entry.date)
+            entry.date = date
+
     def parse_editable_str(self, edited):
         """Parses the output of self.editable_str and updates its entries."""
         mod_entries = self._parse(edited)
