@@ -1,20 +1,20 @@
-# Copyright (C) 2012-2021 jrnl contributors
+# Copyright (C) 2012-2022 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
 import argparse
 import re
 import textwrap
 
-from .commands import postconfig_decrypt
-from .commands import postconfig_encrypt
-from .commands import postconfig_import
-from .commands import postconfig_list
-from .commands import preconfig_diagnostic
-from .commands import preconfig_version
-from .output import deprecated_cmd
-from .plugins import EXPORT_FORMATS
-from .plugins import IMPORT_FORMATS
-from .plugins import util
+from jrnl.commands import postconfig_decrypt
+from jrnl.commands import postconfig_encrypt
+from jrnl.commands import postconfig_import
+from jrnl.commands import postconfig_list
+from jrnl.commands import preconfig_diagnostic
+from jrnl.commands import preconfig_version
+from jrnl.output import deprecated_cmd
+from jrnl.plugins import EXPORT_FORMATS
+from jrnl.plugins import IMPORT_FORMATS
+from jrnl.plugins import util
 
 
 class WrappingFormatter(argparse.RawTextHelpFormatter):
@@ -243,10 +243,10 @@ def parse_args(args=[]):
     reading.add_argument(
         "-not",
         dest="excluded",
-        nargs="?",
+        nargs=1,
         default=[],
         metavar="TAG",
-        action="append",
+        action="extend",
         help="Exclude entries with this tag",
     )
 
@@ -267,6 +267,14 @@ def parse_args(args=[]):
         action="store_true",
         help="Interactively deletes selected entries",
     )
+    exporting.add_argument(
+        "--change-time",
+        dest="change_time",
+        nargs="?",
+        metavar="DATE",
+        const="now",
+        help="Change timestamp for seleted entries (default: now)",
+    )
     exporting.add_argument(
         "--format",
         metavar="TYPE",
