@@ -1,16 +1,21 @@
+# Copyright (C) 2012-2022 jrnl contributors
+# License: https://www.gnu.org/licenses/gpl-3.0.html
+
 import logging
 import os
-import sys
 
 import colorama
-import yaml
 import xdg.BaseDirectory
+from ruamel.yaml import YAML
 
-from . import __version__
-from .exception import JrnlError
-from .color import ERROR_COLOR
-from .color import RESET_COLOR
-from .output import list_journals
+from jrnl import __version__
+from jrnl.exception import JrnlException
+from jrnl.messages import Message
+from jrnl.messages import MsgStyle
+from jrnl.messages import MsgText
+from jrnl.output import list_journals
+from jrnl.output import print_msg
+from jrnl.path import home_dir
 
 # Constants
 DEFAULT_CONFIG_NAME = "jrnl.yaml"
@@ -42,7 +47,8 @@ def make_yaml_valid_dict(input: list) -> dict:
 
     # yaml compatible strings are of the form Key:Value
     yamlstr = YAML_SEPARATOR.join(input)
-    runtime_modifications = yaml.load(yamlstr, Loader=yaml.SafeLoader)
+
+    runtime_modifications = YAML(typ="safe").load(yamlstr)
 
     return runtime_modifications
 
@@ -50,33 +56,35 @@ def make_yaml_valid_dict(input: list) -> dict:
 def save_config(config, alt_config_path=None):
     """Supply alt_config_path if using an alternate config through --config-file."""
     config["version"] = __version__
+
+    yaml = YAML(typ="safe")
+    yaml.default_flow_style = False  # prevents collapsing of tree structure
+
     with open(
         alt_config_path if alt_config_path else get_config_path(),
         "w",
         encoding=YAML_FILE_ENCODING,
     ) as f:
-        yaml.safe_dump(
-            config,
-            f,
-            encoding=YAML_FILE_ENCODING,
-            allow_unicode=True,
-            default_flow_style=False,
-        )
+        yaml.dump(config, f)
 
 
 def get_config_path():
     try:
         config_directory_path = xdg.BaseDirectory.save_config_path(XDG_RESOURCE)
     except FileExistsError:
-        raise JrnlError(
-            "ConfigDirectoryIsFile",
-            config_directory_path=os.path.join(
-                xdg.BaseDirectory.xdg_config_home, XDG_RESOURCE
+        raise JrnlException(
+            Message(
+                MsgText.ConfigDirectoryIsFile,
+                MsgStyle.ERROR,
+                {
+                    "config_directory_path": os.path.join(
+                        xdg.BaseDirectory.xdg_config_home, XDG_RESOURCE
+                    )
+                },
             ),
         )
-    return os.path.join(
-        config_directory_path or os.path.expanduser("~"), DEFAULT_CONFIG_NAME
-    )
+
+    return os.path.join(config_directory_path or home_dir(), DEFAULT_CONFIG_NAME)
 
 
 def get_default_config():
@@ -103,9 +111,7 @@ def get_default_config():
 
 
 def get_default_journal_path():
-    journal_data_path = xdg.BaseDirectory.save_data_path(
-        XDG_RESOURCE
-    ) or os.path.expanduser("~")
+    journal_data_path = xdg.BaseDirectory.save_data_path(XDG_RESOURCE) or home_dir()
     return os.path.join(journal_data_path, DEFAULT_JOURNAL_NAME)
 
 
@@ -137,11 +143,15 @@ def verify_config_colors(config):
         if upper_color == "NONE":
             continue
         if not getattr(colorama.Fore, upper_color, None):
-            print(
-                "[{2}ERROR{3}: {0} set to invalid color: {1}]".format(
-                    key, color, ERROR_COLOR, RESET_COLOR
-                ),
-                file=sys.stderr,
+            print_msg(
+                Message(
+                    MsgText.InvalidColor,
+                    MsgStyle.NORMAL,
+                    {
+                        "key": key,
+                        "color": color,
+                    },
+                )
             )
             all_valid_colors = False
     return all_valid_colors
@@ -150,7 +160,9 @@ def verify_config_colors(config):
 def load_config(config_path):
     """Tries to load a config file from YAML."""
     with open(config_path, encoding=YAML_FILE_ENCODING) as f:
-        return yaml.load(f, Loader=yaml.SafeLoader)
+        yaml = YAML(typ="safe")
+        yaml.allow_duplicate_keys = True
+        return yaml.load(f)
 
 
 def is_config_json(config_path):
@@ -186,9 +198,13 @@ def get_journal_name(args, config):
             args.text = args.text[1:]
 
     if args.journal_name not in config["journals"]:
-        print("No default journal configured.", file=sys.stderr)
-        print(list_journals(config), file=sys.stderr)
-        sys.exit(1)
+        raise JrnlException(
+            Message(
+                MsgText.NoDefaultJournal,
+                MsgStyle.ERROR,
+                {"journals": list_journals(config)},
+            ),
+        )
 
     logging.debug("Using journal name: %s", args.journal_name)
     return args
