@@ -1,17 +1,15 @@
-# encoding: utf-8
-# Copyright (C) 2012-2021 jrnl contributors
+# Copyright (C) 2012-2022 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
-from .fancy_exporter import FancyExporter
-from .jrnl_importer import JRNLImporter
-from .json_exporter import JSONExporter
-from .markdown_exporter import MarkdownExporter
-from .tag_exporter import TagExporter
-from .dates_exporter import DatesExporter
-from .template_exporter import __all__ as template_exporters
-from .text_exporter import TextExporter
-from .xml_exporter import XMLExporter
-from .yaml_exporter import YAMLExporter
+from jrnl.plugins.dates_exporter import DatesExporter
+from jrnl.plugins.fancy_exporter import FancyExporter
+from jrnl.plugins.jrnl_importer import JRNLImporter
+from jrnl.plugins.json_exporter import JSONExporter
+from jrnl.plugins.markdown_exporter import MarkdownExporter
+from jrnl.plugins.tag_exporter import TagExporter
+from jrnl.plugins.text_exporter import TextExporter
+from jrnl.plugins.xml_exporter import XMLExporter
+from jrnl.plugins.yaml_exporter import YAMLExporter
 
 __exporters = [
     JSONExporter,
@@ -22,7 +20,7 @@ __exporters = [
     XMLExporter,
     YAMLExporter,
     FancyExporter,
-] + template_exporters
+]
 __importers = [JRNLImporter]
 
 __exporter_types = {name: plugin for plugin in __exporters for name in plugin.names}
