@@ -1,9 +1,9 @@
-# encoding: utf-8
-# Copyright (C) 2012-2021 jrnl contributors
+# Copyright (C) 2012-2022 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
+
 from collections import Counter
 
-from .text_exporter import TextExporter
+from jrnl.plugins.text_exporter import TextExporter
 
 
 class DatesExporter(TextExporter):
