@@ -1,11 +1,13 @@
-# encoding: utf-8
-# Copyright (C) 2012-2021 jrnl contributors
+# Copyright (C) 2012-2022 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
-from jrnl.exception import JrnlError
 from textwrap import TextWrapper
 
-from .text_exporter import TextExporter
+from jrnl.exception import JrnlException
+from jrnl.messages import Message
+from jrnl.messages import MsgStyle
+from jrnl.messages import MsgText
+from jrnl.plugins.text_exporter import TextExporter
 
 
 class FancyExporter(TextExporter):
@@ -40,7 +42,7 @@ class FancyExporter(TextExporter):
         card = [
             cls.border_a + cls.border_b * (initial_linewrap) + cls.border_c + date_str
         ]
-        check_provided_linewrap_viability(linewrap, card, entry.journal)
+        check_provided_linewrap_viability(linewrap, card, entry.journal.name)
 
         w = TextWrapper(
             width=initial_linewrap,
@@ -84,9 +86,14 @@ class FancyExporter(TextExporter):
 def check_provided_linewrap_viability(linewrap, card, journal):
     if len(card[0]) > linewrap:
         width_violation = len(card[0]) - linewrap
-        raise JrnlError(
-            "LineWrapTooSmallForDateFormat",
-            config_linewrap=linewrap,
-            columns=width_violation,
-            journal=journal,
+        raise JrnlException(
+            Message(
+                MsgText.LineWrapTooSmallForDateFormat,
+                MsgStyle.NORMAL,
+                {
+                    "config_linewrap": linewrap,
+                    "columns": width_violation,
+                    "journal": journal,
+                },
+            )
         )
