@@ -1,9 +1,14 @@
-# encoding: utf-8
-# Copyright (C) 2012-2021 jrnl contributors
+# Copyright (C) 2012-2022 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
 import sys
 
+from jrnl.exception import JrnlException
+from jrnl.messages import Message
+from jrnl.messages import MsgStyle
+from jrnl.messages import MsgText
+from jrnl.output import print_msg
+
 
 class JRNLImporter:
     """This plugin imports entries from other jrnl files."""
@@ -22,12 +27,21 @@ class JRNLImporter:
             try:
                 other_journal_txt = sys.stdin.read()
             except KeyboardInterrupt:
-                print("[Entries NOT imported into journal.]", file=sys.stderr)
-                sys.exit(0)
+                raise JrnlException(
+                    Message(MsgText.KeyboardInterruptMsg, MsgStyle.ERROR_ON_NEW_LINE),
+                    Message(MsgText.ImportAborted, MsgStyle.WARNING),
+                )
+
         journal.import_(other_journal_txt)
         new_cnt = len(journal.entries)
-        print(
-            "[{} imported to {} journal]".format(new_cnt - old_cnt, journal.name),
-            file=sys.stderr,
-        )
         journal.write()
+        print_msg(
+            Message(
+                MsgText.ImportSummary,
+                MsgStyle.NORMAL,
+                {
+                    "count": new_cnt - old_cnt,
+                    "journal_name": journal.name,
+                },
+            )
+        )
