@@ -1,9 +1,8 @@
-# encoding: utf-8
-# Copyright (C) 2012-2021 jrnl contributors
+# Copyright (C) 2012-2022 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
-from .text_exporter import TextExporter
-from .util import get_tags_count
+from jrnl.plugins.text_exporter import TextExporter
+from jrnl.plugins.util import get_tags_count
 
 
 class TagExporter(TextExporter):
